class StructuralAttributeBuilderFunctionsQueryBuilder extends GeneralFunctionsQueryBuilder {
  constructor(elements) {
    super(elements);
    this.elements = elements;

    document.querySelectorAll('[data-structural-attr-modal-action-button]').forEach(button => {
      button.addEventListener('click', () => {
        this.actionButtonInStrucAttrModalHandler(button.dataset.structuralAttrModalActionButton);
      });
    });
    document.querySelector('.ent-type-selection-action[data-ent-type="any"]').addEventListener('click', () => {
      this.queryChipFactory('start-empty-entity', 'Entity Start', '<ent>');
      this.queryChipFactory('end-entity', 'Entity End', '</ent>', null, true);
      this.resetAndCloseStructuralAttrModal();
    });
    document.querySelector('.ent-type-selection-action[data-ent-type="english"]').addEventListener('change', (event) => {
      this.queryChipFactory('start-entity', `Entity Type=${event.target.value}`, `<ent_type="${event.target.value}">`);
      this.queryChipFactory('end-entity', 'Entity End', '</ent_type>', null, true);
      this.resetAndCloseStructuralAttrModal();
    });
  }

  actionButtonInStrucAttrModalHandler(action) {
    switch (action) {
      case 'sentence':
        this.queryChipFactory('start-sentence', 'Sentence Start', '<s>');
        this.queryChipFactory('end-sentence', 'Sentence End', '</s>', null, true);
        this.resetAndCloseStructuralAttrModal();
        break;
      case 'entity':
        this.toggleClass(['entity-builder'], 'hide', 'toggle');
        this.toggleClass(['text-annotation-builder'], 'hide', 'add');
        break;
      case 'meta-data':
        this.toggleClass(['text-annotation-builder'], 'hide', 'toggle');
        this.toggleClass(['entity-builder'], 'hide', 'add');
        break;
      default:
        break;
    }
  }

  textAnnotationSubmitHandler() {
    let noValueMetadataMessage = document.querySelector('#corpus-analysis-concordance-no-value-metadata-message');
    let textAnnotationSubmit = document.querySelector('#corpus-analysis-concordance-text-annotation-submit');
    let textAnnotationInput = document.querySelector('#corpus-analysis-concordance-text-annotation-input');
    let textAnnotationOptions = document.querySelector('#corpus-analysis-concordance-text-annotation-options');

    if (textAnnotationInput.value === '') {
      textAnnotationSubmit.classList.add('red');
      noValueMetadataMessage.classList.remove('hide');
      setTimeout(() => {
        textAnnotationSubmit.classList.remove('red');
      }, 500);
      setTimeout(() => {
        noValueMetadataMessage.classList.add('hide');
      }, 3000);
    } else {
      let queryText = `:: match.text_${textAnnotationOptions.value}="${textAnnotationInput.value}"`;
      this.queryChipFactory('text-annotation', `${textAnnotationOptions.value}=${textAnnotationInput.value}`, queryText);
      this.resetAndCloseStructuralAttrModal();
    }
  }

  resetAndCloseStructuralAttrModal() {
    let textAnnotatinInput = document.querySelector('#corpus-analysis-concordance-text-annotation-input');
    textAnnotatinInput.value = '';
    this.resetMaterializeSelection([this.elements.englishEntTypeSelection, this.elements.germanEntTypeSelection]);
    this.resetMaterializeSelection([this.elements.textAnnotationSelection], 'address');

    this.toggleClass(['entity-builder', 'text-annotation-builder'], 'hide', 'add');
    this.elements.structuralAttrModal.close();
  }

}
